@@ -55,7 +55,7 @@ def format_coco_file(imgdir, annotations, train_assets, test_assets):
     train_assets_fname = [e.filename for e in train_assets]
     test_assets_fname = [e.filename for e in test_assets]
     formatted_file_train = {"images": []}
-    formatted_file_test  = {"images": []}
+    formatted_file_test = {"images": []}
     formatted_annotations = {}
     for shape in annotations["annotations"]:
         if shape["image_id"] in formatted_annotations.keys():
@@ -67,11 +67,14 @@ def format_coco_file(imgdir, annotations, train_assets, test_assets):
     for image in annotations["images"]:
         image["path"] = os.path.join(imgdir, image["file_name"])
         tmp = image.copy()
-        tmp["annotations"] = formatted_annotations[image["id"]]
-        if image["file_name"] in train_assets_fname:
-            formatted_file_train["images"].append(tmp)
-        if image["file_name"] in test_assets_fname:
-            formatted_file_test["images"].append(tmp)
+        try:
+            tmp["annotations"] = formatted_annotations[image["id"]]
+            if image["file_name"] in train_assets_fname:
+                formatted_file_train["images"].append(tmp)
+            if image["file_name"] in test_assets_fname:
+                formatted_file_test["images"].append(tmp)
+        except KeyError:
+            pass
     return formatted_file_train, formatted_file_test
 
 
@@ -112,7 +115,7 @@ def create_record_files(
         imgdir=imgdir,
         annotations=annotations,
         train_assets=train_list,
-        test_assets=eval_list
+        test_assets=eval_list,
     )
     label_map = label_map_util.load_labelmap(label_path)
     label_map = label_map_util.get_label_map_dict(label_map)
